package
Version:
v0.0.0-...-4606e03
Opens a new window with list of versions in this module.
Published: Jul 28, 2020
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Routes in the domain route
type Member struct {
ID int64 `json:"id"`
}
Member model
type Repository interface {
}
Repository is the domain storage
Service is the domain service
NewService creates new domain service
Source Files
¶
Click to show internal directories.
Click to hide internal directories.